@@ -1,4 +1,7 @@
+#![recursion_limit = "256"]
+
 mod prelude;
+pub use prelude::NodeTrait;
 pub use prelude::Primitive;
 
 #[rustfmt::skip]
