@@ -5,8 +5,8 @@ use maplit::btreemap;
 use pretty_assertions::assert_eq;
 use serde_json::{json, Result, Value};
 use stencila_schema::{
-    Article, BlockContent, CodeExpression, CreativeWorkAuthors, CreativeWorkTitle, InlineContent,
-    Paragraph, Person, Primitive,
+    Article, BlockContent, CodeExpression, CreativeWorkAuthors, CreativeWorkTitle,
+    CreativeWorkTypes, Entity, InlineContent, NodeTrait, Paragraph, Person, Primitive,
 };
 
 #[test]
@@ -15,10 +15,10 @@ fn primitives_deserialize() -> Result<()> {
     assert!(matches!(null, Primitive::Null));
 
     let bool: Primitive = serde_json::from_str("true")?;
-    assert!(matches!(bool, Primitive::Bool(_)));
+    assert!(matches!(bool, Primitive::Boolean(_)));
 
     let bool: Primitive = serde_json::from_str("false")?;
-    assert!(matches!(bool, Primitive::Bool(_)));
+    assert!(matches!(bool, Primitive::Boolean(_)));
 
     let integer: Primitive = serde_json::from_str("42")?;
     assert!(matches!(integer, Primitive::Integer(_)));
@@ -32,7 +32,7 @@ fn primitives_deserialize() -> Result<()> {
     let array: Primitive = serde_json::from_str(r#"[null, false, 42, 3.14, "string"]"#)?;
     if let Primitive::Array(array) = array {
         assert!(matches!(array[0], Primitive::Null));
-        assert!(matches!(array[1], Primitive::Bool(false)));
+        assert!(matches!(array[1], Primitive::Boolean(false)));
         assert!(matches!(array[2], Primitive::Integer(_)));
         assert!(matches!(array[3], Primitive::Number(_)));
         assert!(matches!(array[4], Primitive::String(_)));
@@ -51,7 +51,7 @@ fn primitives_deserialize() -> Result<()> {
     )?;
     if let Primitive::Object(object) = object {
         assert!(matches!(object["a"], Primitive::Null));
-        assert!(matches!(object["b"], Primitive::Bool(false)));
+        assert!(matches!(object["b"], Primitive::Boolean(false)));
         assert!(matches!(object["c"], Primitive::Integer(_)));
         assert!(matches!(object["d"], Primitive::Number(_)));
         assert!(matches!(object["e"], Primitive::String(_)));
@@ -67,10 +67,10 @@ fn primitives_serialize() -> Result<()> {
     let null = Primitive::Null;
     assert_eq!(serde_json::to_string(&null)?, "null");
 
-    let bool = Primitive::Bool(true);
+    let bool = Primitive::Boolean(true);
     assert_eq!(serde_json::to_string(&bool)?, "true");
 
-    let bool = Primitive::Bool(false);
+    let bool = Primitive::Boolean(false);
     assert_eq!(serde_json::to_string(&bool)?, "false");
 
     let integer = Primitive::Integer(42);
@@ -84,7 +84,7 @@ fn primitives_serialize() -> Result<()> {
 
     let array = Primitive::Array(vec![
         Primitive::Null,
-        Primitive::Bool(false),
+        Primitive::Boolean(false),
         Primitive::Integer(42),
         Primitive::Number(3.14),
         Primitive::String("string".to_string()),
@@ -96,7 +96,7 @@ fn primitives_serialize() -> Result<()> {
 
     let object = Primitive::Object(btreemap! {
         "a".to_string() => Primitive::Null,
-        "b".to_string() => Primitive::Bool(false),
+        "b".to_string() => Primitive::Boolean(false),
         "c".to_string() => Primitive::Integer(42),
         "d".to_string() => Primitive::Number(3.14),
         "e".to_string() => Primitive::String("string".to_string())
@@ -194,3 +194,33 @@ fn entity_is_serdeable() -> Result<()> {
 
     Ok(())
 }
+
+#[test]
+fn entity_has_type_name() {
+    let article = Article::default();
+
+    assert_eq!(article.type_name(), "Article")
+}
+
+#[test]
+fn entity_has_id() {
+    let id = Some("whateva".into());
+    let entity = Entity {
+        id: id.clone(),
+        ..Default::default()
+    };
+
+    assert_eq!(entity.id(), id)
+}
+
+#[test]
+fn union_types_have_typename_and_id() {
+    let id = Some("whateva".into());
+    let work = CreativeWorkTypes::Article(Article {
+        id: id.clone(),
+        ..Default::default()
+    });
+
+    assert_eq!(work.type_name(), "Article");
+    assert_eq!(work.id(), id)
+}
